# -*- coding: utf-8 -*-

"""
Extensions that introduce `basename` and `dirname` as Jinja2 filters.

Examples
--------

    my_path = "/some/absolute/path/with/file.txt"
    {{ my_path | basename }}

Will fill in `file.txt`.
"""

from __future__ import absolute_import

import os.path

from jinja2.ext import Extension

__all__ = ("OSPathExtension",)


class OSPathExtension(Extension):
    """A Jinja2 extension that introduces `os.path` functionality."""

    tags = frozenset(["basename", "dirname"])

    def __init__(self, environment):
        """Initialize the extension and prepare the Jinja2 environment."""
        super(OSPathExtension, self).__init__(environment)
        for name in self.tags:
            environment.filters[name] = getattr(os.path, name)



# -*- coding: utf-8 -*-

"""Jinja2 extensions that introduce `os.path` functions as template filters."""

from __future__ import absolute_import

from .extensions import *

__author__ = "Moritz E. Beber"
__email__ = "morbeb@biosustain.dtu.dk"
__version__ = "0.1.0"



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from __future__ import absolute_import

from setuptools import setup, find_packages

with open("README.md") as readme_file:
    readme = readme_file.read()

requirements = [
    "jinja2"
]

test_requirements = [
    "tox"
]

setup(
    name="jinja2_ospath",
    version="0.1.0",
    description="A Jinja2 extension that introduces the filters basename and dirname.",
    long_description=readme,
    author="Moritz Emanuel Beber",
    author_email="midnighter@posteo.net",
    url="https://github.com/Midnighter/jinja2_ospath",
    packages=find_packages(),
    include_package_data=False,
    install_requires=requirements,
    license="3-Clause BSD License",
    zip_safe=False,
    keywords="jinja2 extension os.path dirname basename",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Natural Language :: English",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6"
    ]
)
